You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [2/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ mai...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbortException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbortException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbortException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortException.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortWithHttpStatusException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbortWithHttpStatusException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortWithHttpStatusException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbortWithHttpStatusException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortWithHttpStatusException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbortWithHttpStatusException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbortWithHttpStatusException.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import javax.servlet.http.HttpServletResponse;
 
-import wicket.protocol.http.WebResponse;
-import wicket.request.target.basic.EmptyRequestTarget;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.request.target.basic.EmptyRequestTarget;
+
 
 /**
  * Causes Wicket to abort processing and set the specified HTTP status code. An
@@ -31,7 +32,7 @@
  * @author Igor Vaynberg (ivaynberg)
  * @author Gili Tzabari
  * @see HttpServletResponse
- * @deprecated moves to package wicket.protocol.http.servlet in 2.0
+ * @deprecated moves to package org.apache.wicket.protocol.http.servlet in 2.0
  */
 public class AbortWithHttpStatusException extends AbortException
 {
@@ -66,7 +67,7 @@
 			if (!(r instanceof WebResponse))
 			{
 				throw new IllegalStateException(
-						"This exception can only be thrown when wicket is processing an http request");
+						"This exception can only be thrown when org.apache.wicket is processing an http request");
 			}
 
 			WebResponse wr = (WebResponse)r;

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbstractRestartResponseException.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbstractRestartResponseException.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbstractRestartResponseException.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbstractRestartResponseException.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbstractRestartResponseException.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AbstractRestartResponseException.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AbstractRestartResponseException.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 /**
  * An exception that causes the request cycle to immediately switch to respond

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AccessStackPageMap.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AccessStackPageMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AccessStackPageMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AccessStackPageMap.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AccessStackPageMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AccessStackPageMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AccessStackPageMap.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Iterator;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.session.pagemap.IPageMapEntry;
+import org.apache.wicket.util.collections.ArrayListStack;
 
-import wicket.session.pagemap.IPageMapEntry;
-import wicket.util.collections.ArrayListStack;
 
 /**
  * A container for pages held in the session. IPageMap is a parameter to several

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Application.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Application.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Application.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Application.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Application.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IClusterable.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IClusterable.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.Serializable;
 

Added: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IComponentBorder.java
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IComponentBorder.java?view=auto&rev=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IComponentBorder.java (added)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IComponentBorder.java Tue Apr 10 11:15:14 2007
@@ -0,0 +1,44 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.wicket;
+
+import java.io.Serializable;
+
+import org.apache.wicket.markup.html.border.MarkupComponentBorder;
+
+/**
+ * This class gives you call backs to genererate swing like borders.
+ * 
+ * @author jcompagner
+ * 
+ * @see MarkupComponentBorder
+ */
+public interface IComponentBorder extends Serializable
+{
+	/**
+	 * Called before the component is rendered.
+	 * @param component
+	 */
+	public void renderBefore(Component component);
+	
+	/**
+	 * Called after the component is renderd.
+	 * @param component
+	 */
+	public void renderAfter(Component component);
+
+}

Propchange: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IComponentBorder.java
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IConverterLocator.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IConverterLocator.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IConverterLocator.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IConverterLocator.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IConverterLocator.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IConverterLocator.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IConverterLocator.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.settings.IApplicationSettings;
-import wicket.util.convert.ConverterLocator;
-import wicket.util.convert.IConverter;
-import wicket.util.convert.IConverterLocatorFactory;
+import org.apache.wicket.settings.IApplicationSettings;
+import org.apache.wicket.util.convert.ConverterLocator;
+import org.apache.wicket.util.convert.IConverter;
+import org.apache.wicket.util.convert.IConverterLocatorFactory;
 
 /**
  * Locates the proper converter instance for a given type. Classes that

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IDestroyer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IDestroyer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IDestroyer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IDestroyer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IDestroyer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IDestroyer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IDestroyer.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 /**
  * Optional interface for {@link IInitializer initializers} that can clean up

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IInitializer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IInitializer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IInitializer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IInitializer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IInitializer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IPageMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageMap.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.session.pagemap.IPageMapEntry;
+import org.apache.wicket.session.pagemap.IPageMapEntry;
 
 /**
  * @author eelcohillenius

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRedirectListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRedirectListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRedirectListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRedirectListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRedirectListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRedirectListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRedirectListener.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 /**
  * Request listener called on page redirects.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestCycleFactory.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestCycleFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestCycleFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestCycleFactory.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestCycleFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestCycleFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestCycleFactory.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 
 /**

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestListener.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 
 /**
@@ -27,7 +27,7 @@
  * best way to do this is to create a public static final constant field in your
  * request listener interface. Doing this will cause the interface to
  * automatically register whenever it is used. For example, see
- * {@link wicket.IRedirectListener#INTERFACE}.
+ * {@link org.apache.wicket.IRedirectListener#INTERFACE}.
  * 
  * @author Jonathan Locke
  */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestTarget.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestTarget.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestTarget.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestTarget.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestTarget.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IRequestTarget.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IRequestTarget.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 /**
  * <p>

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceFactory.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResourceFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResourceFactory.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResourceListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceListener.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.request.RequestParameters;
-import wicket.request.target.resource.ComponentResourceRequestTarget;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.resource.ComponentResourceRequestTarget;
 
 /**
  * Listens for requests regarding resources. Such resources are typically
@@ -30,8 +30,8 @@
  * (instead of referencing static images in their markup) can be distributed as
  * a self-contained JAR file.
  * 
- * @see wicket.markup.html.image.Image
- * @see wicket.markup.html.image.resource.RenderedDynamicImageResource
+ * @see org.apache.wicket.markup.html.image.Image
+ * @see org.apache.wicket.markup.html.image.resource.RenderedDynamicImageResource
  * @author Jonathan Locke
  */
 public interface IResourceListener extends IRequestListener

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResponseFilter.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResponseFilter.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResponseFilter.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResponseFilter.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResponseFilter.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/ISessionFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ISessionFactory.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 /**
  * A factory interface used by Applications to create Sessions.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Initializer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Initializer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Initializer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Initializer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Initializer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MarkupFragmentFinder.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupFragmentFinder.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupElement;
-import wicket.markup.MarkupStream;
-import wicket.markup.html.border.Border;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupElement;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.html.border.Border;
 
 /**
  * Responding to an AJAX request requires that we position the markup stream at

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataEntry.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MetaDataEntry.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataEntry.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MetaDataEntry.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataEntry.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MetaDataEntry.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataEntry.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.Serializable;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataKey.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MetaDataKey.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataKey.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MetaDataKey.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataKey.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MetaDataKey.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MetaDataKey.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.Serializable;
 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Page.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Page.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Page.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Page.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Page.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/PageMap.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageMap.java Tue Apr 10 11:15:14 2007
@@ -14,15 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import wicket.request.target.basic.RedirectRequestTarget;
-import wicket.session.pagemap.IPageMapEntry;
-import wicket.util.lang.Objects;
+import org.apache.wicket.request.target.basic.RedirectRequestTarget;
+import org.apache.wicket.session.pagemap.IPageMapEntry;
+import org.apache.wicket.util.lang.Objects;
+
 
 /**
  * @author jcompagner
@@ -97,7 +98,7 @@
 
 
 	/**
-	 * @see wicket.IPageMap#attributeForId(int)
+	 * @see org.apache.wicket.IPageMap#attributeForId(int)
 	 */
 	public final String attributeForId(final int id)
 	{
@@ -105,7 +106,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#clear()
+	 * @see org.apache.wicket.IPageMap#clear()
 	 */
 	public void clear()
 	{
@@ -147,12 +148,12 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#get(int, int)
+	 * @see org.apache.wicket.IPageMap#get(int, int)
 	 */
 	public abstract Page get(final int id, int versionNumber);
 
 	/**
-	 * @see wicket.IPageMap#getEntry(int)
+	 * @see org.apache.wicket.IPageMap#getEntry(int)
 	 */
 	public final IPageMapEntry getEntry(final int id)
 	{
@@ -160,7 +161,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#getName()
+	 * @see org.apache.wicket.IPageMap#getName()
 	 */
 	public final String getName()
 	{
@@ -168,7 +169,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#getSession()
+	 * @see org.apache.wicket.IPageMap#getSession()
 	 */
 	public final Session getSession()
 	{
@@ -176,7 +177,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#getSizeInBytes()
+	 * @see org.apache.wicket.IPageMap#getSizeInBytes()
 	 */
 	public final long getSizeInBytes()
 	{
@@ -198,7 +199,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#isDefault()
+	 * @see org.apache.wicket.IPageMap#isDefault()
 	 */
 	public final boolean isDefault()
 	{
@@ -206,7 +207,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#nextId()
+	 * @see org.apache.wicket.IPageMap#nextId()
 	 */
 	public final int nextId()
 	{
@@ -215,7 +216,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#put(wicket.Page)
+	 * @see org.apache.wicket.IPageMap#put(org.apache.wicket.Page)
 	 */
 	public abstract void put(final Page page);
 
@@ -284,7 +285,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#remove()
+	 * @see org.apache.wicket.IPageMap#remove()
 	 */
 	public final void remove()
 	{
@@ -296,7 +297,7 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#remove(wicket.Page)
+	 * @see org.apache.wicket.IPageMap#remove(org.apache.wicket.Page)
 	 */
 	public final void remove(final Page page)
 	{
@@ -305,12 +306,12 @@
 	}
 
 	/**
-	 * @see wicket.IPageMap#removeEntry(wicket.session.pagemap.IPageMapEntry)
+	 * @see org.apache.wicket.IPageMap#removeEntry(org.apache.wicket.session.pagemap.IPageMapEntry)
 	 */
 	public abstract void removeEntry(final IPageMapEntry entry);
 
 	/**
-	 * @see wicket.IPageMap#setSession(wicket.Session)
+	 * @see org.apache.wicket.IPageMap#setSession(org.apache.wicket.Session)
 	 */
 	public final void setSession(final Session session)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageParameters.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/PageParameters.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageParameters.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/PageParameters.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageParameters.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/PageParameters.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageParameters.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Map;
 
-import wicket.protocol.http.RequestUtils;
-import wicket.util.string.IStringIterator;
-import wicket.util.string.StringList;
-import wicket.util.value.ValueMap;
+import org.apache.wicket.protocol.http.RequestUtils;
+import org.apache.wicket.util.string.IStringIterator;
+import org.apache.wicket.util.string.StringList;
+import org.apache.wicket.util.value.ValueMap;
+
 
 /**
  * A typesafe abstraction and container for parameters to a requested page. Page

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Request.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Request.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Request.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Request.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Request.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Request.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Request.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Locale;
 import java.util.Map;
 
-import wicket.request.IRequestCodingStrategy;
-import wicket.request.IRequestCycleProcessor;
-import wicket.request.RequestParameters;
+import org.apache.wicket.request.IRequestCodingStrategy;
+import org.apache.wicket.request.IRequestCycleProcessor;
+import org.apache.wicket.request.RequestParameters;
+
 
 /**
  * Base class for page request implementations allowing access to request

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestCycle.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/RequestCycle.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestCycle.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/RequestCycle.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestCycle.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/RequestCycle.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestCycle.java Tue Apr 10 11:15:14 2007
@@ -14,32 +14,32 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Iterator;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.behavior.IBehavior;
+import org.apache.wicket.protocol.http.BufferedWebResponse;
+import org.apache.wicket.protocol.http.IRequestLogger;
+import org.apache.wicket.protocol.http.PageExpiredException;
+import org.apache.wicket.request.ClientInfo;
+import org.apache.wicket.request.IRequestCodingStrategy;
+import org.apache.wicket.request.IRequestCycleProcessor;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
+import org.apache.wicket.request.target.component.BookmarkablePageRequestTarget;
+import org.apache.wicket.request.target.component.ComponentRequestTarget;
+import org.apache.wicket.request.target.component.IBookmarkablePageRequestTarget;
+import org.apache.wicket.request.target.component.IPageRequestTarget;
+import org.apache.wicket.request.target.component.PageRequestTarget;
+import org.apache.wicket.request.target.component.listener.BehaviorRequestTarget;
+import org.apache.wicket.request.target.component.listener.ListenerInterfaceRequestTarget;
+import org.apache.wicket.request.target.resource.SharedResourceRequestTarget;
+import org.apache.wicket.util.collections.ArrayListStack;
+import org.apache.wicket.util.value.ValueMap;
 
-import wicket.behavior.IBehavior;
-import wicket.protocol.http.BufferedWebResponse;
-import wicket.protocol.http.IRequestLogger;
-import wicket.protocol.http.PageExpiredException;
-import wicket.request.ClientInfo;
-import wicket.request.IRequestCodingStrategy;
-import wicket.request.IRequestCycleProcessor;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.BookmarkableListenerInterfaceRequestTarget;
-import wicket.request.target.component.BookmarkablePageRequestTarget;
-import wicket.request.target.component.ComponentRequestTarget;
-import wicket.request.target.component.IBookmarkablePageRequestTarget;
-import wicket.request.target.component.IPageRequestTarget;
-import wicket.request.target.component.PageRequestTarget;
-import wicket.request.target.component.listener.BehaviorRequestTarget;
-import wicket.request.target.component.listener.ListenerInterfaceRequestTarget;
-import wicket.request.target.resource.SharedResourceRequestTarget;
-import wicket.util.collections.ArrayListStack;
-import wicket.util.value.ValueMap;
 
 /**
  * THIS CLASS IS DELIBERATELY NOT INSTANTIABLE BY FRAMEWORK CLIENTS AND IS NOT
@@ -95,7 +95,7 @@
  * session-relative number:
  * <p>
  * <ul>
- * /[Application]?wicket:interface=[pageMapName]:[pageId]: ...
+ * /[Application]?org.apache.wicket:interface=[pageMapName]:[pageId]: ...
  * </ul>
  * <p>
  * Often, the reason to access an existing session page is due to some kind of
@@ -104,13 +104,13 @@
  * registered listener is dispatched like so:
  * <p>
  * <ul>
- * /[Application]?wicket:interface=[pageMapName]:[pageId]:[componentPath]:[version]:[interfaceName]
+ * /[Application]?org.apache.wicket:interface=[pageMapName]:[pageId]:[componentPath]:[version]:[interfaceName]
  * </ul>
  * <p>
  * For example:
  * <p>
  * <ul>
- * /[Application]?wicket:interface=:3:signInForm:submit::IFormSubmitListener
+ * /[Application]?org.apache.wicket:interface=:3:signInForm:submit::IFormSubmitListener
  * </ul>
  * </td>
  * </tr>
@@ -432,7 +432,7 @@
 	/**
 	 * Template method that is called when a runtime exception is thrown, just
 	 * before the actual handling of the runtime exception. This is called by
-	 * {@link wicket.request.compound.DefaultExceptionResponseStrategy}, hence
+	 * {@link org.apache.wicket.request.compound.DefaultExceptionResponseStrategy}, hence
 	 * if that strategy is replaced by another one, there is no guarantee this
 	 * method is called.
 	 * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestListenerInterface.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/RequestListenerInterface.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestListenerInterface.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/RequestListenerInterface.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestListenerInterface.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/RequestListenerInterface.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/RequestListenerInterface.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -24,11 +24,11 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.authorization.AuthorizationException;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.listener.ListenerInterfaceRequestTarget;
+import org.apache.wicket.util.lang.Classes;
 
-import wicket.authorization.AuthorizationException;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.listener.ListenerInterfaceRequestTarget;
-import wicket.util.lang.Classes;
 
 /**
  * Base class for request listener interfaces.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Resource.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Resource.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Resource.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Resource.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Resource.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Response.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Response.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -29,13 +29,13 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.protocol.http.WebApplication;
+import org.apache.wicket.util.io.Streams;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.time.Time;
 
-import wicket.markup.ComponentTag;
-import wicket.protocol.http.WebApplication;
-import wicket.util.io.Streams;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
-import wicket.util.time.Time;
 
 /**
  * Abstract base class for different implementations of response writing. A
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Application.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Application.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -30,39 +30,39 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.application.IComponentInstantiationListener;
+import org.apache.wicket.markup.MarkupCache;
+import org.apache.wicket.markup.html.image.resource.DefaultButtonImageResourceFactory;
+import org.apache.wicket.markup.parser.filter.WicketMessageTagHandler;
+import org.apache.wicket.markup.resolver.AutoComponentResolver;
+import org.apache.wicket.markup.resolver.EnclosureResolver;
+import org.apache.wicket.markup.resolver.FragmentResolver;
+import org.apache.wicket.markup.resolver.HtmlHeaderResolver;
+import org.apache.wicket.markup.resolver.MarkupInheritanceResolver;
+import org.apache.wicket.markup.resolver.ParentResolver;
+import org.apache.wicket.markup.resolver.WicketContainerResolver;
+import org.apache.wicket.markup.resolver.WicketLinkResolver;
+import org.apache.wicket.markup.resolver.WicketMessageResolver;
+import org.apache.wicket.protocol.http.IRequestLogger;
+import org.apache.wicket.protocol.http.RequestLogger;
+import org.apache.wicket.session.ISessionStore;
+import org.apache.wicket.settings.IApplicationSettings;
+import org.apache.wicket.settings.IDebugSettings;
+import org.apache.wicket.settings.IExceptionSettings;
+import org.apache.wicket.settings.IFrameworkSettings;
+import org.apache.wicket.settings.IMarkupSettings;
+import org.apache.wicket.settings.IPageSettings;
+import org.apache.wicket.settings.IRequestCycleSettings;
+import org.apache.wicket.settings.IRequestLoggerSettings;
+import org.apache.wicket.settings.IResourceSettings;
+import org.apache.wicket.settings.ISecuritySettings;
+import org.apache.wicket.settings.ISessionSettings;
+import org.apache.wicket.settings.Settings;
+import org.apache.wicket.util.file.IResourceFinder;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.util.lang.Objects;
+import org.apache.wicket.util.time.Duration;
 
-import wicket.application.IComponentInstantiationListener;
-import wicket.markup.MarkupCache;
-import wicket.markup.html.image.resource.DefaultButtonImageResourceFactory;
-import wicket.markup.parser.filter.WicketMessageTagHandler;
-import wicket.markup.resolver.AutoComponentResolver;
-import wicket.markup.resolver.EnclosureResolver;
-import wicket.markup.resolver.FragmentResolver;
-import wicket.markup.resolver.HtmlHeaderResolver;
-import wicket.markup.resolver.MarkupInheritanceResolver;
-import wicket.markup.resolver.ParentResolver;
-import wicket.markup.resolver.WicketContainerResolver;
-import wicket.markup.resolver.WicketLinkResolver;
-import wicket.markup.resolver.WicketMessageResolver;
-import wicket.protocol.http.IRequestLogger;
-import wicket.protocol.http.RequestLogger;
-import wicket.session.ISessionStore;
-import wicket.settings.IApplicationSettings;
-import wicket.settings.IDebugSettings;
-import wicket.settings.IExceptionSettings;
-import wicket.settings.IFrameworkSettings;
-import wicket.settings.IMarkupSettings;
-import wicket.settings.IPageSettings;
-import wicket.settings.IRequestCycleSettings;
-import wicket.settings.IRequestLoggerSettings;
-import wicket.settings.IResourceSettings;
-import wicket.settings.ISecuritySettings;
-import wicket.settings.ISessionSettings;
-import wicket.settings.Settings;
-import wicket.util.file.IResourceFinder;
-import wicket.util.lang.Classes;
-import wicket.util.lang.Objects;
-import wicket.util.time.Duration;
 
 /**
  * Base class for all Wicket applications. To create a Wicket application, you
@@ -79,7 +79,7 @@
  * override getHomePage() to provide this property value.
  * 
  * <li><b>Settings </b>- Application settings are partitioned into sets of
  * related settings using interfaces in the wicket.settings package. These
  * interfaces are returned by the following methods, which should be used to
  * configure framework settings for your application: getApplicationSettings(),
  * getDebugSettings(), getExceptionSettings(), getMarkupSettings(),
@@ -97,7 +97,7 @@
  * referee) and will yield a stable URL, permitting efficient browser caching of
  * the resource (even if the resource is dynamically generated). Resources
  * shared in this manner may also be localized. See
  * {@link wicket.ResourceReference} for more details.
  * 
  * <li><b>Session Factory </b>- The Application subclass WebApplication
  * supplies an implementation of getSessionFactory() which returns an
@@ -108,7 +108,7 @@
  * 
  * </ul>
  * 
- * @see wicket.protocol.http.WebApplication
+ * @see org.apache.wicket.protocol.http.WebApplication
  * @author Jonathan Locke
  */
 public abstract class Application
@@ -270,7 +270,7 @@
 		addComponentInstantiationListener(new IComponentInstantiationListener()
 		{
 			/**
-			 * @see wicket.application.IComponentInstantiationListener#onInstantiation(wicket.Component)
+			 * @see org.apache.wicket.application.IComponentInstantiationListener#onInstantiation(org.apache.wicket.Component)
 			 */
 			public void onInstantiation(final Component component)
 			{
@@ -291,7 +291,7 @@
 	 * Adds a component instantiation listener. This method should typicaly only
 	 * be called during application startup; it is not thread safe.
 	 * <p>
 	 * Note: wicket does not guarantee the execution order of added listeners
 	 * 
 	 * @param listener
 	 *            the listener to add
@@ -326,7 +326,7 @@
 	 * 
 	 * @param configurationType
 	 *            The configuration type (either DEVELOPMENT or DEPLOYMENT)
-	 * @see wicket.Application#configure(String, IResourceFinder)
+	 * @see org.apache.wicket.Application#configure(String, IResourceFinder)
 	 */
 	public final void configure(final String configurationType)
 	{
@@ -341,9 +341,9 @@
 	 *            The configuration type. Must currently be either DEVELOPMENT
 	 *            or DEPLOYMENT. Currently, if the configuration type is
 	 *            DEVELOPMENT, resources are polled for changes, component usage
 	 *            is checked, wicket tags are not stripped from ouput and a
 	 *            detailed exception page is used. If the type is DEPLOYMENT,
 	 *            component usage is not checked, wicket tags are stripped from
 	 *            output and a non-detailed exception page is used to display
 	 *            errors.
 	 * @param resourceFinder
@@ -617,16 +617,16 @@
 	/**
 	 * THIS METHOD IS NOT PART OF THE WICKET PUBLIC API. DO NOT CALL.
 	 * 
 	 * Initializes wicket components.
 	 */
 	public final void initializeComponents()
 	{
 		// Load any wicket properties files we can find
 		try
 		{
 			// Load properties files used by all libraries
 			final Enumeration resources = getClass().getClassLoader().getResources(
-					"wicket.properties");
+					"org.apache.wicket.properties");
 			while (resources.hasMoreElements())
 			{
 				InputStream in = null;
@@ -816,7 +816,7 @@
 	}
 
 	/**
 	 * Called when wicket servlet is destroyed. Overrides do not have to call
 	 * super.
 	 */
 	protected void destroy()
@@ -79,7 +79,7 @@
  * 
  * <li><b>Settings </b>- Application settings are partitioned into sets of
- * related settings using interfaces in the wicket.settings package. These
+ * related settings using interfaces in the org.apache.wicket.settings package. These
  * interfaces are returned by the following methods, which should be used to
  * configure framework settings for your application: getApplicationSettings(),
@@ -97,7 +97,7 @@
  * the resource (even if the resource is dynamically generated). Resources
  * shared in this manner may also be localized. See
- * {@link wicket.ResourceReference} for more details.
+ * {@link org.apache.wicket.ResourceReference} for more details.
  * 
  * <li><b>Session Factory </b>- The Application subclass WebApplication
@@ -291,7 +291,7 @@
 	 * be called during application startup; it is not thread safe.
 	 * <p>
-	 * Note: wicket does not guarantee the execution order of added listeners
+	 * Note: org.apache.wicket does not guarantee the execution order of added listeners
 	 * 
 	 * @param listener
@@ -341,9 +341,9 @@
 	 *            or DEPLOYMENT. Currently, if the configuration type is
 	 *            DEVELOPMENT, resources are polled for changes, component usage
-	 *            is checked, wicket tags are not stripped from ouput and a
+	 *            is checked, org.apache.wicket tags are not stripped from ouput and a
 	 *            detailed exception page is used. If the type is DEPLOYMENT,
@@ -341,9 +341,9 @@
 	 *            detailed exception page is used. If the type is DEPLOYMENT,
-	 *            component usage is not checked, wicket tags are stripped from
+	 *            component usage is not checked, org.apache.wicket tags are stripped from
 	 *            output and a non-detailed exception page is used to display
 	 *            errors.
@@ -617,16 +617,16 @@
 	 * THIS METHOD IS NOT PART OF THE WICKET PUBLIC API. DO NOT CALL.
 	 * 
-	 * Initializes wicket components.
+	 * Initializes org.apache.wicket components.
 	 */
 	public final void initializeComponents()
@@ -617,16 +617,16 @@
 	public final void initializeComponents()
 	{
-		// Load any wicket properties files we can find
+		// Load any org.apache.wicket properties files we can find
 		try
 		{
@@ -816,7 +816,7 @@
 
 	/**
-	 * Called when wicket servlet is destroyed. Overrides do not have to call
+	 * Called when org.apache.wicket servlet is destroyed. Overrides do not have to call
 	 * super.
 	 */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AttributeModifier.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AttributeModifier.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AttributeModifier.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AttributeModifier.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AttributeModifier.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/AttributeModifier.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/AttributeModifier.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.behavior.AbstractBehavior;
-import wicket.markup.ComponentTag;
-import wicket.markup.parser.XmlTag;
-import wicket.model.IComponentAssignedModel;
-import wicket.model.IModel;
-import wicket.util.value.IValueMap;
+import org.apache.wicket.behavior.AbstractBehavior;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.parser.XmlTag;
+import org.apache.wicket.model.IComponentAssignedModel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.value.IValueMap;
 
 /**
  * This class allows a tag attribute of a component to be modified dynamically
@@ -44,7 +44,7 @@
  * </p>
  * <p>
  * Instances of this class should be added to components via the
  * {@link wicket.Component#add(AttributeModifier)} method after the component
  * has been constucted.
  * <p>
  * It is possible to create new subclasses of AttributeModifier by overriding
@@ -191,7 +191,7 @@
 	/**
 	 * Made final to support the parameterless variant.
 	 * 
-	 * @see wicket.behavior.AbstractBehavior#isEnabled(wicket.Component)
+	 * @see org.apache.wicket.behavior.AbstractBehavior#isEnabled(org.apache.wicket.Component)
 	 */
 	public boolean isEnabled(Component component)
 	{
@@ -210,8 +210,8 @@
 	}
 
 	/**
-	 * @see wicket.behavior.IBehavior#onComponentTag(wicket.Component,
-	 *      wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.behavior.IBehavior#onComponentTag(org.apache.wicket.Component,
+	 *      org.apache.wicket.markup.ComponentTag)
 	 */
 	public final void onComponentTag(Component component, ComponentTag tag)
 	{
@@ -44,7 +44,7 @@
  * <p>
  * Instances of this class should be added to components via the
- * {@link wicket.Component#add(AttributeModifier)} method after the component
+ * {@link org.apache.wicket.Component#add(AttributeModifier)} method after the component
  * has been constucted.
  * <p>

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Component.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Component.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Component.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Component.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -25,32 +25,32 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.ajax.AjaxRequestTarget;
+import org.apache.wicket.authorization.Action;
+import org.apache.wicket.authorization.AuthorizationException;
+import org.apache.wicket.authorization.IAuthorizationStrategy;
+import org.apache.wicket.authorization.UnauthorizedActionException;
+import org.apache.wicket.behavior.IBehavior;
+import org.apache.wicket.feedback.FeedbackMessage;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupException;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.WicketTag;
+import org.apache.wicket.markup.html.IHeaderContributor;
+import org.apache.wicket.markup.html.internal.HtmlHeaderContainer;
+import org.apache.wicket.model.IComponentAssignedModel;
+import org.apache.wicket.model.IComponentInheritedModel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.IModelComparator;
+import org.apache.wicket.model.IWrapModel;
+import org.apache.wicket.util.convert.IConverter;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.util.lang.Objects;
+import org.apache.wicket.util.string.PrependingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.value.ValueMap;
+import org.apache.wicket.version.undo.Change;
 
-import wicket.ajax.AjaxRequestTarget;
-import wicket.authorization.Action;
-import wicket.authorization.AuthorizationException;
-import wicket.authorization.IAuthorizationStrategy;
-import wicket.authorization.UnauthorizedActionException;
-import wicket.behavior.IBehavior;
-import wicket.feedback.FeedbackMessage;
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupException;
-import wicket.markup.MarkupStream;
-import wicket.markup.WicketTag;
-import wicket.markup.html.IHeaderContributor;
-import wicket.markup.html.internal.HtmlHeaderContainer;
-import wicket.model.IComponentAssignedModel;
-import wicket.model.IComponentInheritedModel;
-import wicket.model.IModel;
-import wicket.model.IModelComparator;
-import wicket.model.IWrapModel;
-import wicket.util.convert.IConverter;
-import wicket.util.lang.Classes;
-import wicket.util.lang.Objects;
-import wicket.util.string.PrependingStringBuffer;
-import wicket.util.string.Strings;
-import wicket.util.value.ValueMap;
-import wicket.version.undo.Change;
 
 /**
  * Component serves as the highest level abstract base class for all components.
@@ -103,7 +103,7 @@
  * listener interface directly is highly discouraged. Instead, calls to
  * listeners are routed through logic specific to the event, resulting in calls
  * to user code through other overridable methods. For example, the
- * {@link wicket.markup.html.form.IFormSubmitListener#onFormSubmitted()} method
+ * {@link org.apache.wicket.markup.html.form.IFormSubmitListener#onFormSubmitted()} method
  * implemented by the Form class is really a private implementation detail of
  * the Form class that is not designed to be overridden (although unfortunately,
  * it must be public since all interface methods in Java must be public).
@@ -204,7 +204,7 @@
  * 
  * <li><b>Page Factory </b>- It is possible to change the way that Pages are
  * constructed by overriding the {@link Component#getPageFactory()} method,
  * returning your own implementation of {@link wicket.IPageFactory}.
  * 
  * <li><b>Versioning </b>- Pages are the unit of versioning in Wicket, but
  * fine-grained control of which Components should participate in versioning is
@@ -254,7 +254,7 @@
 		}
 
 		/**
-		 * @see wicket.version.undo.Change#undo()
+		 * @see org.apache.wicket.version.undo.Change#undo()
 		 */
 		public void undo()
 		{
@@ -263,6 +263,24 @@
 	}
 
 	/**
+	 * Undo change for component border property
+	 * 
+	 * @author ivaynberg
+	 */
+	private class ComponentBorderChange extends Change
+	{
+		private static final long serialVersionUID = 1L;
+
+		private final IComponentBorder old = getComponentBorder();
+
+		public void undo()
+		{
+			setComponentBorder(old);
+		}
+
+	}
+
+	/**
 	 * Generic component visitor interface for component traversals.
 	 */
 	public static interface IVisitor
@@ -329,7 +347,7 @@
 		}
 
 		/**
-		 * @see wicket.version.undo.Change#undo()
+		 * @see org.apache.wicket.version.undo.Change#undo()
 		 */
 		public void undo()
 		{
@@ -371,7 +389,7 @@
 		}
 
 		/**
-		 * @see wicket.version.undo.Change#undo()
+		 * @see org.apache.wicket.version.undo.Change#undo()
 		 */
 		public void undo()
 		{
@@ -508,6 +526,12 @@
 	private static final int FLAG_DETACHING					= 0x80000000;
 
 
+	/** meta data key for missing body tags logging. */
+	private static final MetaDataKey BORDER_KEY = new MetaDataKey(IComponentBorder.class)
+	{
+		private static final long serialVersionUID = 1L;
+	};
+	
 	/** Basic model IModelComparator implementation for normal object models */
 	private static final IModelComparator defaultModelComparator = new IModelComparator()
 	{
@@ -879,7 +903,7 @@
 	 * Retrieves id by which this component is represented within the markup.
 	 * <p>
 	 * The point of this function is to generate a unique id to make it easy to
-	 * locate this component in the generated markup for post-wicket processing
+	 * locate this component in the generated markup for post-org.apache.wicket processing
 	 * such as javascript or an xslt transform.
 	 * <p>
 	 * Note: This method should only be called after the component or its parent
@@ -1173,12 +1197,12 @@
 	}
 
 	/**
 	 * Gets the style of this component (see {@link wicket.Session}).
 	 * 
 	 * @return The style of this component.
 	 * 
-	 * @see wicket.Session
-	 * @see wicket.Session#getStyle()
+	 * @see org.apache.wicket.Session
+	 * @see org.apache.wicket.Session#getStyle()
 	 */
 	public final String getStyle()
 	{
@@ -1502,7 +1526,16 @@
 				notifyBehaviorsComponentBeforeRender();
 				try
 				{
+					final IComponentBorder border = getComponentBorder();
+					if (border != null)
+					{
+						border.renderBefore(this);
+					}
 					onRender(markupStream);
+					if (border != null)
+					{
+						border.renderAfter(this);
+					}
 				}
 				finally
 				{
@@ -2076,6 +2109,33 @@
 	public final Component setRenderBodyOnly(final boolean renderTag)
 	{
 		this.setFlag(FLAG_RENDER_BODY_ONLY, renderTag);
+		return this;
+	}
+
+	/**
+	 * @return component border assigned to this component, or null if none
+	 */
+	public final IComponentBorder getComponentBorder()
+	{
+		return (IComponentBorder)getMetaData(BORDER_KEY);
+	}
+
+	/**
+	 * Assigns a component border to this component. If called with
+	 * <code>null</code> any previous border will be cleared.
+	 * 
+	 * @param border
+	 *            componnet border to assign, or <code>null</code> to clear
+	 *            any previous
+	 * @return component for chaining
+	 */
+	public final Component setComponentBorder(final IComponentBorder border)
+	{
+		if (!Objects.equal(getComponentBorder(), border))
+		{
+			addStateChange(new ComponentBorderChange());
+		}
+		setMetaData(BORDER_KEY, border);
 		return this;
 	}
 
@@ -204,7 +204,7 @@
  * <li><b>Page Factory </b>- It is possible to change the way that Pages are
  * constructed by overriding the {@link Component#getPageFactory()} method,
- * returning your own implementation of {@link wicket.IPageFactory}.
+ * returning your own implementation of {@link org.apache.wicket.IPageFactory}.
  * 
  * <li><b>Versioning </b>- Pages are the unit of versioning in Wicket, but
@@ -1173,12 +1197,12 @@
 
 	/**
-	 * Gets the style of this component (see {@link wicket.Session}).
+	 * Gets the style of this component (see {@link org.apache.wicket.Session}).
 	 * 
 	 * @return The style of this component.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IClusterable.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IClusterable.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IClusterable.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IClusterable.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IClusterable.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IInitializer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IInitializer.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.markup.html.PackageResource;
+import org.apache.wicket.markup.html.PackageResource;
 
 /**
  * Initializes something when application loads.
@@ -32,7 +32,7 @@
  * they can be initialized lazily.
  * </p>
  * <p>
  * Initializers can be configured by having a wicket.properties file in the
  * class path root, with property 'initializer=${initializer class name}'. You
  * can have one such properties per jar file, but the initializer that property
  * denotes can delegate to other initializers of that library.
@@ -32,7 +32,7 @@
  * </p>
  * <p>
- * Initializers can be configured by having a wicket.properties file in the
+ * Initializers can be configured by having a org.apache.wicket.properties file in the
  * class path root, with property 'initializer=${initializer class name}'. You
  * can have one such properties per jar file, but the initializer that property

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageFactory.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IPageFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IPageFactory.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IPageFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageFactory.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 
 /**
@@ -22,10 +22,10 @@
  * without a PageParameters argument to pass to the Page's constructor.
  * <p>
  * IMPORTANT NOTE: Implementations must let subclasses of
  * {@link wicket.AbstractRestartResponseException} thrown from the constructing
  * page' constructor bubble up.
  * 
- * @see wicket.settings.ISessionSettings#setPageFactory(IPageFactory)
+ * @see org.apache.wicket.settings.ISessionSettings#setPageFactory(IPageFactory)
  * @see Session#getPageFactory()
  * @see Session#getPageFactory(Page)
  * 
@@ -22,10 +22,10 @@
  * <p>
  * IMPORTANT NOTE: Implementations must let subclasses of
- * {@link wicket.AbstractRestartResponseException} thrown from the constructing
+ * {@link org.apache.wicket.AbstractRestartResponseException} thrown from the constructing
  * page' constructor bubble up.
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageMap.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IPageMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IPageMap.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IPageMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResourceFactory.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceFactory.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Locale;
 
@@ -25,7 +25,7 @@
  * might include settings relevant to buttons such as the width, height and
  * color of the button, as well as the text to draw on the button.
  * 
- * @see wicket.markup.html.image.resource.LocalizedImageResource
+ * @see org.apache.wicket.markup.html.image.resource.LocalizedImageResource
  * @author Jonathan Locke
  */
 public interface IResourceFactory
@@ -36,7 +36,7 @@
 	 * @param locale
 	 *            The locale for the resource
 	 * @param style
 	 *            The style of the resource (see {@link wicket.Session})
 	 * @return The resource
 	 */
 	Resource newResource(final String specification, final Locale locale, final String style);
@@ -36,7 +36,7 @@
 	 *            The locale for the resource
 	 * @param style
-	 *            The style of the resource (see {@link wicket.Session})
+	 *            The style of the resource (see {@link org.apache.wicket.Session})
 	 * @return The resource
 	 */

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResourceListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResourceListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResourceListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/IResponseFilter.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/IResponseFilter.java Tue Apr 10 11:15:14 2007
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.AppendingStringBuffer;
 
 /**
  * A response filter can be added to the
- * {@link wicket.settings.IRequestCycleSettings#addResponseFilter(IResponseFilter)} object
+ * {@link org.apache.wicket.settings.IRequestCycleSettings#addResponseFilter(IResponseFilter)} object
  * The will be called from the Buffered Response objects right before they would send it to the
  * real responses. You have to use the
  * {@link wicket.settings.IRequestCycleSettings#setBufferResponse(boolean)}(to true which is the default)
  * for this filtering to work.
  * 
  * @author jcompagner
  * 
- * @see wicket.settings.IRequestCycleSettings#addResponseFilter(IResponseFilter)
+ * @see org.apache.wicket.settings.IRequestCycleSettings#addResponseFilter(IResponseFilter)
  */
 public interface IResponseFilter
 {
@@ -14,21 +14,21 @@
  * The will be called from the Buffered Response objects right before they would send it to the
  * real responses. You have to use the
- * {@link wicket.settings.IRequestCycleSettings#setBufferResponse(boolean)}(to true which is the default)
+ * {@link org.apache.wicket.settings.IRequestCycleSettings#setBufferResponse(boolean)}(to true which is the default)
  * for this filtering to work.
  * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ISessionFactory.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/ISessionFactory.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ISessionFactory.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/ISessionFactory.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ISessionFactory.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Initializer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Initializer.java Tue Apr 10 11:15:14 2007
@@ -14,23 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
-import wicket.behavior.IBehaviorListener;
-import wicket.behavior.IUnversionedBehaviorListener;
-import wicket.markup.html.form.IFormSubmitListener;
-import wicket.markup.html.form.IOnChangeListener;
-import wicket.markup.html.link.ILinkListener;
+import org.apache.wicket.behavior.IBehaviorListener;
+import org.apache.wicket.behavior.IUnversionedBehaviorListener;
+import org.apache.wicket.markup.html.form.IFormSubmitListener;
+import org.apache.wicket.markup.html.form.IOnChangeListener;
+import org.apache.wicket.markup.html.link.ILinkListener;
 
 /**
  * Initializer for components in wicket core library.
  * 
  * @author Jonathan Locke
  */
 public class Initializer implements IInitializer
 {
 	/**
-	 * @see wicket.IInitializer#init(wicket.Application)
+	 * @see org.apache.wicket.IInitializer#init(org.apache.wicket.Application)
 	 */
 	public void init(Application application)
 	{
@@ -14,23 +14,23 @@
 
 /**
- * Initializer for components in wicket core library.
+ * Initializer for components in org.apache.wicket core library.
  * 
  * @author Jonathan Locke

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Localizer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Localizer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Localizer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Localizer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Localizer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Localizer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Localizer.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Iterator;
 import java.util.Locale;
 import java.util.MissingResourceException;
 
-import wicket.model.IModel;
-import wicket.resource.loader.IStringResourceLoader;
-import wicket.settings.IResourceSettings;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.interpolator.PropertyVariableInterpolator;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.resource.loader.IStringResourceLoader;
+import org.apache.wicket.settings.IResourceSettings;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.interpolator.PropertyVariableInterpolator;
+
 
 /**
  * A utility class that encapsulates all of the localization related
@@ -37,9 +38,9 @@
  * loaders which load the properties from a database. There should be no need to
  * extend Localizer.
  * 
  * @see wicket.settings.Settings#getLocalizer()
  * @see wicket.resource.loader.IStringResourceLoader
  * @see wicket.settings.Settings#getStringResourceLoaders()
  * 
  * @author Chris Turner
  * @author Juergen Donnerstag
@@ -37,9 +38,9 @@
  * extend Localizer.
  * 
- * @see wicket.settings.Settings#getLocalizer()
- * @see wicket.resource.loader.IStringResourceLoader
- * @see wicket.settings.Settings#getStringResourceLoaders()
+ * @see org.apache.wicket.settings.Settings#getLocalizer()
+ * @see org.apache.wicket.resource.loader.IStringResourceLoader
+ * @see org.apache.wicket.settings.Settings#getStringResourceLoaders()
  * 
  * @author Chris Turner

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MarkupContainer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MarkupContainer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MarkupContainer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupContainer.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -25,21 +25,21 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.feedback.IFeedback;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupElement;
+import org.apache.wicket.markup.MarkupException;
+import org.apache.wicket.markup.MarkupNotFoundException;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.WicketTag;
+import org.apache.wicket.markup.resolver.IComponentResolver;
+import org.apache.wicket.model.IComponentInheritedModel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.IWrapModel;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.version.undo.Change;
 
-import wicket.feedback.IFeedback;
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupElement;
-import wicket.markup.MarkupException;
-import wicket.markup.MarkupNotFoundException;
-import wicket.markup.MarkupStream;
-import wicket.markup.WicketTag;
-import wicket.markup.resolver.IComponentResolver;
-import wicket.model.IComponentInheritedModel;
-import wicket.model.IModel;
-import wicket.model.IWrapModel;
-import wicket.util.resource.IResourceStream;
-import wicket.util.string.Strings;
-import wicket.version.undo.Change;
 
 /**
  * A MarkupContainer holds a map of child components.
@@ -104,7 +104,7 @@
 	private transient MarkupStream markupStream;
 
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public MarkupContainer(final String id)
 	{
@@ -112,7 +112,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public MarkupContainer(final String id, IModel model)
 	{
@@ -287,7 +287,7 @@
 
 		// If the container is transparent, than ask its parent.
 		// ParentResolver does something quite similar, but because of <head>,
 		// <body>, <wicket:panel> etc. it is quite common to have transparent
 		// components. Hence, this is little short cut for a tiny performance
 		// optimization.
 		if ((child == null) && isTransparentResolver() && (getParent() != null))
@@ -341,7 +341,7 @@
 							+ "' for component '"
 							+ getClass().getName()
 							+ "' not found."
-							+ " Enable debug messages for wicket.util.resource to get a list of all filenames tried"),
+							+ " Enable debug messages for org.apache.wicket.util.resource to get a list of all filenames tried"),
 					ex);
 		}
 	}
@@ -403,7 +403,7 @@
 	 * transparent container gets its children from its parent container.
 	 * <p>
 	 * 
-	 * @see wicket.markup.resolver.ParentResolver
+	 * @see org.apache.wicket.markup.resolver.ParentResolver
 	 * 
 	 * @return false. By default a MarkupContainer is not transparent.
 	 */
@@ -671,7 +671,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#setModel(wicket.model.IModel)
+	 * @see org.apache.wicket.Component#setModel(org.apache.wicket.model.IModel)
 	 */
 	public Component setModel(final IModel model)
 	{
@@ -715,7 +715,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#toString()
+	 * @see org.apache.wicket.Component#toString()
 	 */
 	public String toString()
 	{
@@ -1141,7 +1141,7 @@
 		// Get the current markup element
 		final MarkupElement element = markupStream.get();
 
 		// If it a tag like <wicket..> or <span wicket:id="..." >
 		if ((element instanceof ComponentTag) && !markupStream.atCloseTag())
 		{
 			// Get element as tag
@@ -1194,7 +1194,7 @@
 					if (((WicketTag)tag).isChildTag())
 					{
 						markupStream.throwMarkupException("Found " + tag.toString()
-								+ " but no <wicket:extend>");
+								+ " but no <org.apache.wicket:extend>");
 					}
 					else
 					{
@@ -287,7 +287,7 @@
 		// If the container is transparent, than ask its parent.
 		// ParentResolver does something quite similar, but because of <head>,
-		// <body>, <wicket:panel> etc. it is quite common to have transparent
+		// <body>, <org.apache.wicket:panel> etc. it is quite common to have transparent
 		// components. Hence, this is little short cut for a tiny performance
 		// optimization.
@@ -1141,7 +1141,7 @@
 		final MarkupElement element = markupStream.get();
 
-		// If it a tag like <wicket..> or <span wicket:id="..." >
+		// If it a tag like <org.apache.wicket..> or <span wicket:id="..." >
 		if ((element instanceof ComponentTag) && !markupStream.atCloseTag())
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupFragmentFinder.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MarkupFragmentFinder.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupFragmentFinder.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/MarkupFragmentFinder.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/MarkupFragmentFinder.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Page.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Page.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.ArrayList;
 import java.util.HashSet;
@@ -23,24 +23,24 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.authorization.UnauthorizedActionException;
+import org.apache.wicket.feedback.IFeedback;
+import org.apache.wicket.markup.MarkupException;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.html.WebPage;
+import org.apache.wicket.markup.html.form.Form;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.session.pagemap.IPageMapEntry;
+import org.apache.wicket.settings.IDebugSettings;
+import org.apache.wicket.util.concurrent.ConcurrentHashMap;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.util.lang.Objects;
+import org.apache.wicket.util.string.StringValue;
+import org.apache.wicket.util.value.Count;
+import org.apache.wicket.version.IPageVersionManager;
+import org.apache.wicket.version.undo.Change;
 
-import wicket.authorization.UnauthorizedActionException;
-import wicket.feedback.IFeedback;
-import wicket.markup.MarkupException;
-import wicket.markup.MarkupStream;
-import wicket.markup.html.WebPage;
-import wicket.markup.html.form.Form;
-import wicket.model.IModel;
-import wicket.request.RequestParameters;
-import wicket.session.pagemap.IPageMapEntry;
-import wicket.settings.IDebugSettings;
-import wicket.util.concurrent.ConcurrentHashMap;
-import wicket.util.lang.Classes;
-import wicket.util.lang.Objects;
-import wicket.util.string.StringValue;
-import wicket.util.value.Count;
-import wicket.version.IPageVersionManager;
-import wicket.version.undo.Change;
 
 /**
  * Abstract base class for pages. As a MarkupContainer subclass, a Page can
@@ -75,7 +75,7 @@
  * resides alongside the Java code by default. All MarkupContainers are also
  * Component containers. Through nesting, of containers, a Page can contain any
  * arbitrary tree of Components. For more details on MarkupContainers, see
- * {@link wicket.MarkupContainer}.
+ * {@link org.apache.wicket.MarkupContainer}.
  * 
  * <li><b>Bookmarkable Pages </b>- Pages can be constructed with any
  * constructor when they are being used in a Wicket session, but if you wish to
@@ -90,7 +90,7 @@
  * <li><b>Models </b>- Pages, like other Components, can have models (see
  * {@link IModel}). A Page can be assigned a model by passing one to the Page's
  * constructor, by overriding initModel() or with an explicit invocation of
  * setModel(). If the model is a {@link wicket.model.CompoundPropertyModel},
  * Components on the Page can use the Page's model implicitly via container
  * inheritance. If a Component is not assigned a model, the initModel() override
  * in Component will cause that Component to use the nearest CompoundModel in
@@ -118,13 +118,13 @@
  * be used to allow a user to authenticate themselves if they were denied
  * access.
  * 
  * @see wicket.markup.html.WebPage
  * @see wicket.MarkupContainer
  * @see wicket.model.CompoundPropertyModel
  * @see wicket.model.BoundCompoundPropertyModel
  * @see wicket.Component
  * @see wicket.version.IPageVersionManager
  * @see wicket.version.undo.UndoPageVersionManager
  * 
  * @author Jonathan Locke
  * @author Chris Turner
@@ -407,7 +407,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#getId()
+	 * @see org.apache.wicket.Component#getId()
 	 */
 	public final String getId()
 	{
@@ -415,7 +415,7 @@
 	}
 
 	/**
-	 * @see wicket.session.pagemap.IPageMapEntry#getNumericId()
+	 * @see org.apache.wicket.session.pagemap.IPageMapEntry#getNumericId()
 	 */
 	public int getNumericId()
 	{
@@ -423,7 +423,7 @@
 	}
 
 	/**
-	 * @see wicket.session.pagemap.IPageMapEntry#getPageClass()
+	 * @see org.apache.wicket.session.pagemap.IPageMapEntry#getPageClass()
 	 */
 	public final Class getPageClass()
 	{
@@ -469,7 +469,7 @@
 	 * getStatelessHint() of every component on page (and it's behavior) must
 	 * return true and the page must be bookmarkable.
 	 * 
-	 * @see wicket.Component#getStatelessHint()
+	 * @see org.apache.wicket.Component#getStatelessHint()
 	 */
 	public final boolean getStatelessHint()
 	{
@@ -710,7 +710,7 @@
 	/**
 	 * Redirect to this page.
 	 * 
-	 * @see wicket.IRedirectListener#onRedirect()
+	 * @see org.apache.wicket.IRedirectListener#onRedirect()
 	 */
 	public final void onRedirect()
 	{
@@ -1183,7 +1183,7 @@
 	 * THIS METHOD IS NOT PART OF THE WICKET PUBLIC API. DO NOT CALL OR
 	 * OVERRIDE.
 	 * 
-	 * @see wicket.Component#internalOnModelChanged()
+	 * @see org.apache.wicket.Component#internalOnModelChanged()
 	 */
 	protected final void internalOnModelChanged()
 	{
@@ -1226,7 +1226,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onDetach()
+	 * @see org.apache.wicket.Component#onDetach()
 	 */
 	protected void onDetach()
 	{
@@ -90,7 +90,7 @@
  * {@link IModel}). A Page can be assigned a model by passing one to the Page's
  * constructor, by overriding initModel() or with an explicit invocation of
- * setModel(). If the model is a {@link wicket.model.CompoundPropertyModel},
+ * setModel(). If the model is a {@link org.apache.wicket.model.CompoundPropertyModel},
  * Components on the Page can use the Page's model implicitly via container
  * inheritance. If a Component is not assigned a model, the initModel() override
@@ -118,13 +118,13 @@
  * access.
  * 
- * @see wicket.markup.html.WebPage
- * @see wicket.MarkupContainer
- * @see wicket.model.CompoundPropertyModel
- * @see wicket.model.BoundCompoundPropertyModel
- * @see wicket.Component
- * @see wicket.version.IPageVersionManager
- * @see wicket.version.undo.UndoPageVersionManager
+ * @see org.apache.wicket.markup.html.WebPage
+ * @see org.apache.wicket.MarkupContainer
+ * @see org.apache.wicket.model.CompoundPropertyModel
+ * @see org.apache.wicket.model.BoundCompoundPropertyModel
+ * @see org.apache.wicket.Component
+ * @see org.apache.wicket.version.IPageVersionManager
+ * @see org.apache.wicket.version.undo.UndoPageVersionManager
  * 
  * @author Jonathan Locke

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageMap.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/PageMap.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageMap.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/PageMap.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/PageMap.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Resource.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Resource.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.request.target.resource.ResourceStreamRequestTarget;
+import org.apache.wicket.util.resource.IResourceStream;
+import org.apache.wicket.util.time.Time;
+import org.apache.wicket.util.value.ValueMap;
 
-import wicket.request.target.resource.ResourceStreamRequestTarget;
-import wicket.util.resource.IResourceStream;
-import wicket.util.time.Time;
-import wicket.util.value.ValueMap;
 
 /**
  * A Resource is something that implements IResourceListener and provides a
@@ -112,7 +112,7 @@
 			// Get servlet response to use when responding with resource
 			final Response response = cycle.getResponse();
 
 			// FIXME WICKET-385 Move HTTP caching features out of wicket.Resource
 			if (isCacheable())
 			{
 				response.setLastModifiedTime(resourceStream.lastModifiedTime());
@@ -112,7 +112,7 @@
 			final Response response = cycle.getResponse();
 
-			// FIXME WICKET-385 Move HTTP caching features out of wicket.Resource
+			// FIXME WICKET-385 Move HTTP caching features out of org.apache.wicket.Resource
 			if (isCacheable())
 			{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ResourceReference.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/ResourceReference.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ResourceReference.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/ResourceReference.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ResourceReference.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/ResourceReference.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/ResourceReference.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket;
+package org.apache.wicket;
 
 import java.util.Locale;
 
-import wicket.markup.html.PackageResource;
-import wicket.util.lang.Objects;
+import org.apache.wicket.markup.html.PackageResource;
+import org.apache.wicket.util.lang.Objects;
+
 
 /**
  * ResourceReference is essentially a reference to an actual resource which is
@@ -114,7 +115,7 @@
 	 * Contructs a resource reference with Application.class scope and the given
 	 * name. All resource references constructed with this constructor must have
 	 * unique names since they all have the same Application-wide scope that is
-	 * the wicket.Application.class
+	 * the org.apache.wicket.Application.class
 	 * 
 	 * @param name
 	 *            The name of the resource
@@ -230,7 +231,7 @@
 	}
 
 	/**
 	 * @return Returns the style. (see {@link wicket.Session})
 	 */
 	public final String getStyle()
 	{
@@ -271,7 +272,7 @@
 
 	/**
 	 * @param style
 	 *            The style to set (see {@link wicket.Session}).
 	 */
 	public final void setStyle(String style)
 	{
@@ -230,7 +231,7 @@
 
 	/**
-	 * @return Returns the style. (see {@link wicket.Session})
+	 * @return Returns the style. (see {@link org.apache.wicket.Session})
 	 */
 	public final String getStyle()
@@ -271,7 +272,7 @@
 	/**
 	 * @param style
-	 *            The style to set (see {@link wicket.Session}).
+	 *            The style to set (see {@link org.apache.wicket.Session}).
 	 */
 	public final void setStyle(String style)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Response.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Response.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Response.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/Response.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/Response.java&r2=527232
==============================================================================